import * as VueDemi from 'vue-demi';
import { createModuleLoader } from './core/moduleLoader';
import { createComponentLoader } from './core/componentLoader';
import { ModuleLoaderSymbol, setActiveLoader, setOptions, addErrorHandler, removeErrorHandler } from './register';
import { getUmdResolver } from './resolvers/umd';
/**
 * create module loader
 * @param options options
 * @param options.resolver remote module resolver, default to umd resolver
 * @param options.container container to append script, default is append to body in client side
 */
export function createLoader(options) {
    var _b, _c;
    if (options === void 0) { options = {}; }
    // Set global VueDemi
    if (window && !window.VueDemi) {
        window.VueDemi = VueDemi;
    }
    var _resolver = (_c = (_b = options.resolver) === null || _b === void 0 ? void 0 : _b.call(options, options.container)) !== null && _c !== void 0 ? _c : getUmdResolver(options.container);
    var loader = VueDemi.markRaw({
        install: function (app) {
            // this allows calling registerSubModules() outside of a component setup after
            setActiveLoader(loader);
            if (!VueDemi.isVue2) {
                var moduleLoader = createModuleLoader(app, _resolver);
                var componentLoader = createComponentLoader(app, _resolver);
                loader._a = app;
                loader._moduleLoader = moduleLoader;
                loader._componentLoader = componentLoader;
                app.config.globalProperties.$moduleLoader = loader;
                app.provide(ModuleLoaderSymbol, loader);
            }
        },
        setOptions: function (options) {
            setOptions.call(null, options);
            return this;
        },
        addErrorHandler: function (handler) {
            addErrorHandler.call(null, handler);
            return this;
        },
        removeErrorHandler: function (handler) {
            removeErrorHandler.call(null, handler);
            return this;
        },
        resolver: Object.freeze(_resolver),
        // it's actually undefined here
        // @ts-expect-error set in install when using Vue 3
        _a: null,
        // @ts-expect-error set in install when using Vue 3
        _moduleLoader: null,
        // @ts-expect-error set in install when using Vue 3
        _componentLoader: null,
    });
    return loader;
}
