import warning from 'warning';
import { pathToRegexp } from 'path-to-regexp';
import { debug } from '../env';
export function cleanPath(path) {
    return path.replace(/\/(?:\s*\/)+/g, '/');
}
export function getLocation(location, base) {
    if (base === void 0) { base = '/'; }
    var path = location.pathname;
    var pathLowerCase = path.toLowerCase();
    var baseLowerCase = base.toLowerCase();
    // base="/a" shouldn't turn path="/app" into "/a/pp"
    // https://github.com/vuejs/vue-router/issues/3555
    // so we ensure the trailing slash in the base
    if (base && (pathLowerCase === baseLowerCase || pathLowerCase.indexOf(cleanPath(baseLowerCase + '/')) === 0)) {
        path = path.slice(base.length);
    }
    return (path || '/') + window.location.search + window.location.hash;
}
export function compilePathRegex(path, pathToRegexpOptions) {
    var regex = pathToRegexp(path, pathToRegexpOptions);
    if (debug) {
        var _keys_1 = Object.create(null);
        regex.keys.forEach(function (key) {
            warning(!_keys_1[key.name], "Duplicate param keys in route with path: \"".concat(path, "\""));
            _keys_1[key.name] = true;
        });
    }
    return regex;
}
