import type { InjectionKey, Component } from 'vue-demi';
import type { ModuleLoader, ModuleLoaderOptions, RegistrableModule, Lifecycles, Router, ErrorHandler } from './types';
/**
 * inject key
 */
export declare const ModuleLoaderSymbol: InjectionKey<ModuleLoader>;
/**
 * Set or unset active fetch, Used in SSR and internally when calling
 * actions and getters
 * @param loader ModuleLoader instance
 */
export declare const setActiveLoader: (loader: ModuleLoader | undefined) => ModuleLoader<{}, any> | undefined;
/**
 * Get the currently active fetch if there is any.
 */
export declare const getActiveLoader: () => ModuleLoader<{}, any> | undefined;
/**
 * Set ModuleLoader options
 * @param options Options
 */
export declare function setOptions(options: ModuleLoaderOptions): void;
/**
 * Add global error handler
 * @param handler Error handler
 */
export declare function addErrorHandler(handler: ErrorHandler): void;
/**
 * Remove global error handler
 * @param handler Error handler
 */
export declare function removeErrorHandler(handler: ErrorHandler): void;
/**
 * Register sub modules
 * @param config module config
 * @param lifecycles lifecycle
 */
export declare function registerSubModules(config: RegistrableModule | RegistrableModule[], lifecycles?: Lifecycles): (loader?: ModuleLoader) => {
    /**
     * Start module loader
     */
    start: (options?: Pick<ModuleLoaderOptions, 'loading' | 'register'> & {
        router?: Router;
    }) => Promise<void>;
};
/**
 * Register components
 * @param config component config
 */
export declare function registerComponents<T extends Record<string, string | {
    src: string;
    styles?: string | string[];
}>>(config: T): (loader?: ModuleLoader) => Record<keyof T, () => Promise<Component>>;
