"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.compilePathRegex = exports.getLocation = exports.cleanPath = void 0;
var warning_1 = __importDefault(require("warning"));
var path_to_regexp_1 = require("path-to-regexp");
var env_1 = require("../env");
function cleanPath(path) {
    return path.replace(/\/(?:\s*\/)+/g, '/');
}
exports.cleanPath = cleanPath;
function getLocation(location, base) {
    if (base === void 0) { base = '/'; }
    var path = location.pathname;
    var pathLowerCase = path.toLowerCase();
    var baseLowerCase = base.toLowerCase();
    // base="/a" shouldn't turn path="/app" into "/a/pp"
    // https://github.com/vuejs/vue-router/issues/3555
    // so we ensure the trailing slash in the base
    if (base && (pathLowerCase === baseLowerCase || pathLowerCase.indexOf(cleanPath(baseLowerCase + '/')) === 0)) {
        path = path.slice(base.length);
    }
    return (path || '/') + window.location.search + window.location.hash;
}
exports.getLocation = getLocation;
function compilePathRegex(path, pathToRegexpOptions) {
    var regex = (0, path_to_regexp_1.pathToRegexp)(path, pathToRegexpOptions);
    if (env_1.debug) {
        var _keys_1 = Object.create(null);
        regex.keys.forEach(function (key) {
            (0, warning_1.default)(!_keys_1[key.name], "Duplicate param keys in route with path: \"".concat(path, "\""));
            _keys_1[key.name] = true;
        });
    }
    return regex;
}
exports.compilePathRegex = compilePathRegex;
