"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ModuleLoaderVuePlugin = void 0;
var moduleLoader_1 = require("./core/moduleLoader");
var componentLoader_1 = require("./core/componentLoader");
var register_1 = require("./register");
var ModuleLoaderVuePlugin = /** @class */ (function () {
    function ModuleLoaderVuePlugin() {
    }
    ModuleLoaderVuePlugin.install = function (Vue) {
        // Used to avoid multiple mixins being setup
        // when in dev mode and hot module reload
        // https://github.com/vuejs/vue/issues/5089#issuecomment-284260111
        if (Vue.$__module_loader_installed__)
            return;
        // eslint-disable-next-line @typescript-eslint/camelcase
        Vue.$__module_loader_installed__ = true;
        // Equivalent of
        // app.config.globalProperties.$moduleLoader = moduleLoader
        Vue.mixin({
            beforeCreate: function () {
                var options = this.$options;
                if (options.moduleLoader) {
                    var loader = options.moduleLoader;
                    // HACK: taken from provide(): https://github.com/vuejs/composition-api/blob/main/src/apis/inject.ts#L31
                    if (!this._provided) {
                        var provideCache_1 = {};
                        Object.defineProperty(this, '_provided', {
                            get: function () { return provideCache_1; },
                            set: function (v) { return Object.assign(provideCache_1, v); },
                        });
                    }
                    this._provided[register_1.ModuleLoaderSymbol] = loader;
                    // propagate the loader instance in an SSR friendly way
                    // avoid adding it to nuxt twice
                    if (!this.$moduleLoader) {
                        this.$moduleLoader = loader;
                    }
                    // this allows calling registerSubModules() outside of a component setup after
                    (0, register_1.setActiveLoader)(loader);
                    var moduleLoader = (0, moduleLoader_1.createModuleLoader)(Vue, loader.resolver);
                    var componentLoader = (0, componentLoader_1.createComponentLoader)(Vue, loader.resolver);
                    loader._a = this;
                    loader._moduleLoader = moduleLoader;
                    loader._componentLoader = componentLoader;
                }
                else {
                    this.$moduleLoader = (options.parent && options.parent.$moduleLoader) || this;
                }
            },
        });
    };
    return ModuleLoaderVuePlugin;
}());
exports.ModuleLoaderVuePlugin = ModuleLoaderVuePlugin;
// Auto install if it is not done yet and `window` has `Vue`.
// To allow users to avoid auto-installation in some cases,
if (typeof window !== 'undefined' && window.Vue) {
    window.Vue.use(ModuleLoaderVuePlugin);
}
